import {getCurrentInstance} from "@tarojs/runtime";
import Taro, {useReachBottom} from "@tarojs/taro";
import {ManageApi} from "@/api/manage";
import React, {FC, useState} from "react";
import {Button, CustomWrapper, View} from "@tarojs/components";
import VideoCover from "@/components/videoCover/videoCover";
import {curriculum} from "@/api";

interface DelOpt {
  id: number
  findDel: (id: number) => Promise<void>
}

const Del: FC<DelOpt> = ({id, findDel}: DelOpt) => {
  function del() {
    Taro.showModal({
      title: "是否删除课程",
      success({confirm}) {
        confirm && findDel(id)
      }
    })
  }

  return (
    <View className='text-center p-2' onClick={del}>删除</View>
  )
}

let page = 1
const DepCur: FC = () => {
  const {id} = getCurrentInstance()?.router?.params as { id: number }
  const [total, setTotal] = useState<number>(0)
  const [data, setData] = useState<Curriculum[]>([])

  const getData = async (init?: boolean) => {
    try {
      Taro.showLoading({title: "课程查询中"})
      if (init) {
        page += 1
      } else {
        page = 1
      }
      const res = await ManageApi.depCur({id, size: 10, page: page})
      setTotal(res.total)
      const oldData: Curriculum[] = JSON.parse(JSON.stringify(data))
      res.data.forEach(d => {
        const index = oldData.findIndex(c => c.id === d.id)
        if (index === -1) {
          oldData.push(d)
        } else {
          oldData.splice(index, 1, d)
        }
      })
      setData(oldData)
    } catch (e) {
    }
    Taro.hideLoading()
  }


  async function findDel(cur_id: number) {
    try {
      await curriculum.delCur(id, cur_id)
      const index = data.findIndex(d => d.id === cur_id)
      if (index > -1) {
        const oldData: Curriculum[] = JSON.parse(JSON.stringify(data))
        oldData.splice(index, 1)
        setData(oldData)
      }
      Taro.showToast({title: '删除成功'})
    } catch (e) {
    }
  }

  function jumpAddCur() {
    Taro.navigateTo({url: "/pages/manage/addCur/addCur?id=" + id})
  }

  Taro.useDidShow(() => getData())
  useReachBottom(() => {
    if (data.length < total) {
      getData(true)
    }
  })

  return (
    <CustomWrapper>
      <View className='flex p-1 flex-wrap'>
        {data.map(d => <VideoCover
          key={d.id}
          thumb={d.thumb}
          title={<Del id={d.id} findDel={findDel}/>}
          id={d.id}
          depId={id}
          content={d.title}
        />)}
      </View>
      <View className='text-center p-3'>- 暂无更多数据 -</View>
      <Button className='button mt-3' onClick={jumpAddCur}>添加课程</Button>
    </CustomWrapper>
  )
}
export default DepCur
